/*
** Module   : LegacyField.java
** Abstract : Annotation used to set the legacy field name for a DMO property.
**
** Copyright (c) 2013-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 CA  20131015 Created initial version.
** 002 OM  20140117 Added fieldId (support for runtime indexed access for fields).
*/

package com.goldencode.p2j.persist;

import java.lang.annotation.*;

/**
 * Annotation definition to mark a DMO property with its legacy field name.
 */
@Target(ElementType.FIELD)
@Retention(RetentionPolicy.RUNTIME)
public @interface LegacyField
{
   /** The name of the legacy field associated with a DMO property. */
   String name();

   /**
    * The id of this field in the sequence of the fields of the buffer. It is needed by the
    * dynamic <code>bufferField(int)</code> attribute of the <code>BufferImpl</code> for 
    * emulating the <code>BUFFER-FIELD(integer)</code> buffer handle attribute.
    */
   int fieldId();
}
